<?php
namespace Teknisa\MAN\Controllers;

use Zeedhi\Framework\Controller\CrudWithParameterBag;
use Zeedhi\Framework\DataSource;
use Zeedhi\Framework\DataSource\DataSet;
use Zeedhi\Framework\DataSource\Manager;
use Zeedhi\Framework\DataSource\ParameterBag;
use Zeedhi\Framework\DTO;
use Zeedhi\Framework\DTO\Response\Notification;
use Zeedhi\Framework\DTO\Response\Message;
use Zeedhi\Framework\DTO\Response;
use Zeedhi\Framework\DTO\Request;
use Teknisa\MAN\Services;
use Teknisa\MAN\Utilities;
use Teknisa\MAN\Services\RelBaixaEstoqueProdutoService;

class RelBaixaEstoqueProduto {
    protected $dataSourceName = 'vnd71002_relBaixaEstoqueProduto';
    protected $baixaEstoqueProdutoService;
    protected $utilService;
    
    public function __construct (Utilities\Util $utilService, RelBaixaEstoqueProdutoService $baixaEstoqueProdutoService){
        $this->utilService         = $utilService;
        $this->baixaEstoqueProduto = $baixaEstoqueProdutoService;
    }
    
    public function findReport(Request\Filter $request, Response $response){
        $conditions = $this->utilService->getParamsAsArray($request);
        $conditions = $this->handleConditions($conditions);
        $resposta = $this->baixaEstoqueProduto->getReport($conditions);
        $response->addDataSet(new DataSet("vnd71002_relBaixaEstoqueProduto", $resposta));
    }
    
    private function handleConditions (&$conditions) {
        if(!array_key_exists('CDFILIAL', $conditions)) {
            $conditions['CDFILIMOVI'] = array();
            unset($conditions['CDFILIAL']);
        } else {
            $conditions['CDFILIMOVI'] = $conditions['CDFILIAL'];
            unset($conditions['CDFILIAL']);
        }
        
        if(array_key_exists('DTENTRVENDA', $conditions)) {
            $conditions['DTLANCMOVIINI'] = $conditions['DTENTRVENDA'][0];
            $conditions['DTLANCMOVIFIN'] = $conditions['DTENTRVENDA'][1];
            unset($conditions['DTENTRVENDA']);
        }
        
        if(!array_key_exists('PRODINICOMP', $conditions) &&  !array_key_exists('PRODFIMCOMP', $conditions)) {
            $conditions['PRODINICOMP'] = $conditions['PRODFIMCOMP'] = null;
        }else if(!array_key_exists('PRODFIMCOMP', $conditions) ){
            $conditions['PRODFIMCOMP'] = 'zzzzzzzzzz';
        }else{
            $conditions['PRODINICOMP'] = str_replace('%', '', $conditions['PRODINICOMP']);
            $conditions['PRODFIMCOMP'] = str_replace('%', '', $conditions['PRODFIMCOMP']);
        }
        
        if(array_key_exists('CDARVPRODCOMP', $conditions)) {
            $conditions['CDARVPRODCOMP'] = implode('_', $conditions['CDARVPRODCOMP']);
            $conditions['TCDARVPRODCOMP'] = 'E';
        } else if (!array_key_exists('PRODINICOMP', $conditions) && !array_key_exists('PRODFIMCOMP', $conditions)) {
            $conditions['TCDARVPRODCOMP'] = 'T';
            $conditions['CDARVPRODCOMP'] = '';
        } else {
            $conditions['TCDARVPRODCOMP'] = 'E';
            $conditions['CDARVPRODCOMP'] = '';
        }
        
        if(array_key_exists('INTERVALISTA', $conditions)) {
            if($conditions['INTERVALISTA'] == 'V') {
                $conditions['TCDARVPRODCOMP'] = 'T';
                $conditions['CDARVPRODCOMP'] = '';
                $conditions['ARVPRODCOMP'] = '';
                $conditions['CDPRODINICOMP'] = '';
                $conditions['PRODINICOMP'] = '';
                $conditions['CDPRODFIMCOMP'] = '';
                $conditions['PRODFIMCOMP'] = '';
            }
        } else {
            $conditions['TCDARVPRODCOMP'] = 'T';
        }
        
        if( !array_key_exists('PRODINIVENDA', $conditions) &&  !array_key_exists('PRODFIMVENDA', $conditions) ) {
            $conditions['PRODINIVENDA'] = $conditions['PRODFIMVENDA'] = null;
        }else if(!array_key_exists('PRODFIMVENDA', $conditions) ){
            $conditions['PRODFIMVENDA'] = 'zzzzzzzzzz';
        }else{
            $conditions['PRODINIVENDA'] = str_replace('%', '', $conditions['PRODINIVENDA']);
            $conditions['PRODFIMVENDA'] = str_replace('%', '', $conditions['PRODFIMVENDA']);
        }

        if(array_key_exists('CDARVPRODVENDA', $conditions)) {
            $conditions['CDARVPRODVENDA'] = implode('_', $conditions['CDARVPRODVENDA']);
            $conditions['TCDARVPRODVENDA'] = 'E';
        } else if (!array_key_exists('PRODINIVENDA', $conditions) &&  !array_key_exists('PRODFIMVENDA', $conditions)) {
            $conditions['TCDARVPRODVENDA'] = 'T';
            $conditions['CDARVPRODVENDA'] = '';
        } else {
            $conditions['TCDARVPRODVENDA'] = 'E';
            $conditions['CDARVPRODVENDA'] = '';
        }
        
        if(array_key_exists('INTERVALISTAV', $conditions)) {
            if($conditions['INTERVALISTAV'] == 'V') {
                $conditions['TCDARVPRODVENDA'] = 'T';
                $conditions['CDARVPRODVENDA'] = '';
                $conditions['ARVPRODVENDA'] = '';
                $conditions['CDPRODINIVENDA'] = '';
                $conditions['PRODINIVENDA'] = '';
                $conditions['CDPRODFIMVENDA'] = '';
                $conditions['PRODFIMVENDA'] = '';
            }
        } else {
            $conditions['TCDARVPRODVENDA'] = 'T';
        }
        
        return $conditions;
    }
}